@@ -1,7 +1,7 @@
 #
 # This file is part of App-Module-Locate
 #
-# This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.
+# This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -11,7 +11,7 @@ package App::Module::Locate;
 # ABSTRACT: Interface for module locate
 use strict;
 use warnings;
-our $VERSION = '0.2';    # VERSION
+our $VERSION = '0.3';    # VERSION
 1;
 
 __END__
@@ -24,15 +24,15 @@ App::Module::Locate - Interface for module locate
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 AUTHOR
 
-Geistteufel <geistteufel@celogeek.fr>
+celogeek <me@celogeek.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.
+This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
